@@ -141,11 +141,21 @@ static void killpeer(int service_socket)
     exit(EXIT_FAILURE);
   }
   buffer[num] = '\0';
+#ifdef PID_T_IS_LONG_INT
+  peer_id = atol((char *) buffer);
+  fprintf(stderr, "Killing: %ld\n", peer_id);
+#else
   peer_id = atoi((char *) buffer);
   fprintf(stderr, "Killing: %d\n", peer_id);
+#endif
+
   if (kill(peer_id, SIGHUP) < 0)
   {
+#ifdef PID_T_IS_LONG_INT
+    fprintf(stderr, "Cannot kill %ld: %s\n", peer_id, strerror(errno));
+#else
     fprintf(stderr, "Cannot kill %d: %s\n", peer_id, strerror(errno));
+#endif
     exit(EXIT_FAILURE);
   }
   exit(EXIT_SUCCESS);
